// src/index.ts
import { CoinspotPublicApi } from './publicApi';
import { AuthenticatedCoinspotReadOnlyApi } from './authenticatedReadOnlyApi';
import { AuthenticatedCoinspotApi } from './authenticatedApi';
export * from './types';
export class Coinspot {
    public;
    readOnly;
    authenticated;
    apiKeyRequiredMessage = 'API key and secret are required for authenticated operations';
    constructor(apiKey, apiSecret) {
        this.public = new CoinspotPublicApi();
        if (apiKey && apiSecret) {
            this.readOnly = new AuthenticatedCoinspotReadOnlyApi(apiKey, apiSecret);
            this.authenticated = new AuthenticatedCoinspotApi(apiKey, apiSecret);
        }
        else {
            this.readOnly = null;
            this.authenticated = null;
        }
    }
    // ========================================================================
    // Public API
    // ========================================================================
    async latestCoinPrice(coin) {
        return this.public.getLatestCoinPrice(coin);
    }
    async latestPrices() {
        return this.public.getLatestPrices();
    }
    async latestBuyPrice(coin) {
        return this.public.getLatestBuyPrice(coin);
    }
    async latestSellPrice(coin) {
        return this.public.getLatestSellPrice(coin);
    }
    async openOrderList(coin) {
        return this.public.getOpenOrders(coin);
    }
    async completedOrderList(coin) {
        return this.public.getCompletedOrders(coin);
    }
    // ========================================================================
    // Authenticated Read-Only API
    // ========================================================================
    async coinBalance(coin) {
        if (!this.readOnly) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.readOnly.getSingleCoinBalance(coin, 'yes');
    }
    async balance() {
        if (!this.readOnly) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.readOnly.getBalances();
    }
    // ========================================================================
    // Authenticated API, operate on your accounts, buy, sell, etc.
    // ========================================================================
    async coinDepositAddress(coin) {
        if (!this.authenticated) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.authenticated.getCoinDepositAddress(coin);
    }
    async marketBuyOrder(coin, amount, rate) {
        if (!this.authenticated) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.authenticated.placeMarketBuyOrder(coin, amount, rate);
    }
    async marketSellOrder(coin, amount, rate) {
        if (!this.authenticated) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.authenticated.placeMarketSellOrder(coin, amount, rate);
    }
}
// Named export
export const createCoinspotApi = (apiKey, apiSecret) => {
    return new Coinspot(apiKey, apiSecret);
};
// Default export
export default Coinspot;
//# sourceMappingURL=index.js.map